@@ -280,8 +280,17 @@ async_update (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo *info, gpoin
 		text_count = g_strdup_printf (_("%d of %d"), info->file_index, info->files_total);
 		buddy_set_text ("progress-count", text_count);
 		g_free (text_count);
+
+		#warning temporary hack, see bug #325707
+		/* temporary hack that avoids fraction > 1
+		see bug #325707, this is a gnome-vfs issue */
+		gfloat fraction;
+		fraction = (gfloat)(info->total_bytes_copied / info->bytes_total);
+		if (fraction > 1)
+			fraction = 1;
+
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (GET_WIDGET ("progress-progress")), 
-					       (gfloat)info->total_bytes_copied / info->bytes_total);
+					       fraction);
 	}
 
 	if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
@@ -1506,6 +1515,7 @@ products_list_load (void)
 {
 	BugzillaApplication *app;
 	GtkTreeView *view;
+	GtkTreeViewColumn *col;
 	GtkListStore *store;
 	GtkTreeSelection *selection;
 	GtkTreeIter *iter = NULL;
@@ -1513,15 +1523,20 @@ products_list_load (void)
 	view = GTK_TREE_VIEW (GET_WIDGET ("product-list"));
 	selection = gtk_tree_view_get_selection (view);
 	g_object_get (G_OBJECT (view), "model", &store, NULL);
+	col = gtk_tree_view_get_column (view, 0);
 	gtk_list_store_clear (store);
 
 	druid_data.product = NULL;
 
 	if (druid_data.show_products) {
+	        g_object_set (col, "title", _("Product"), NULL);  
+		      
 		g_hash_table_foreach (druid_data.bugzillas, (GHFunc)add_products, store);
 	} else {
+	        g_object_set (col, "title", _("Application"), NULL);  
 		g_slist_foreach (druid_data.applications, (GFunc)add_application, store);
 	}
+
 	gtk_tree_view_columns_autosize (view);
 }
 
