@@ -22,8 +22,6 @@
 
 #include "bug-buddy.h"
 
-#include <gnome.h>
-
 #include <stdio.h>
 
 #include <sys/wait.h>
@@ -32,6 +30,10 @@
 #include <math.h>
 #include <string.h>
 
+#include <glib/gi18n.h>
+#include <gtk/gtkprogressbar.h>
+#include <gtk/gtktextview.h>
+
 #if 0
 #include <libart_lgpl/libart.h>
 #endif
@@ -269,9 +271,9 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 		short_app = strrchr (app, G_DIR_SEPARATOR) + 1;
 	} else {
 		long_app = g_find_program_in_path (app);
-		if (!long_app && g_getenv("GNOME2_PATH")) {
+		if (!long_app) {
 			/* Applets are not in path... */
-			long_app = g_strconcat(g_getenv("GNOME2_PATH"), "/libexec/", app, NULL);
+			long_app = g_strconcat(GNOMELIBEXECDIR,"/", app, NULL);
 		}
 		short_app = app;
 	}	
