@@ -1,12 +1,12 @@
 /* gnome program that crashes
  *
- * Copyright (C) The Free Software Foundation
+ * Copyright (C) Jacob Berkman
  *
- * Author: Jacob Berkman  <jberkman@andrew.cmu.edu>
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Author: Jacob Berkman  <jacob@bug-buddy.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,19 @@
 
 #include "config.h"
 
-#include <gnome.h>
+#include <libgnome/gnome-program.h>
+#include <libgnomeui/gnome-client.h>
+#include <libgnomeui/gnome-ui-init.h>
 
 int
 main (int argc, char *argv[])
 {
 	int *n = NULL;
-	gnome_client_disable_master_connection ();
-	gnome_init (PACKAGE, VERSION, argc, argv);
+	gnome_program_init ("Crashing GNOME Program", VERSION,
+			    LIBGNOMEUI_MODULE,
+			    argc, argv,
+			    GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,
+			    NULL);
 	n[27] = 10-7-78;
 	return 0;
 }
